Welcome to RAVEN, the Rapid, on-source VOEvent Coincidence Monitor.

RAVEN is used in the LVK low-latency alert system in order to find associations
between gravitational waves and other astronomical transients via GraceDb. See the 
following for more details:
https://igwn.readthedocs.io/projects/gwcelery/en/latest/gwcelery.tasks.external_triggers.html
https://igwn.readthedocs.io/projects/gwcelery/en/latest/gwcelery.tasks.raven.html

RAVEN is also designed to be able to perform these tasks via GraceDb in offline searches
as well.

The latest review documentation can be found at the following:
https://wiki.ligo.org/Bursts/RavenReview
https://git.ligo.org/brandon.piotrzkowski/ravenreview

Legacy documentation can be found at the review documentation website:
   https://www.lsc-group.phys.uwm.edu/ligovirgo/cbcnote/GRBreview/RAVEN

A version of this documentation is included as a PDF file in the ```docs/``` subdirectory.


RAVEN can be installed via pip:

```pip install ligo-raven```

To run the reviewed RAVEN unit tests:

```python setup.py test```


Finally, the most current RAVEN development version is always available from the
git repository:

```git clone https://git.ligo.org/lscsoft/raven.git```

Also note that since RAVEN uses GraceDb, an up-to-date certificate is required and
can be generated by:

```ligo-proxy-init albert.einstein```
